use bevy::prelude::*;

use crate::components::Enemy;
use crate::resources::{CurrentStage, EnemySpawnTimer, FormationState};

// Helper to access world directly in check_stage_clear
pub fn check_stage_clear(world: &mut World) {
    // Use manual resource access because we need mutable access to multiple resources
    // Separate checks to manage borrows correctly
    let mut should_clear = false;
    if let Some(stage) = world.get_resource::<CurrentStage>() {
        if stage.waiting_for_clear {
            // Create the query *after* checking the flag
            let mut enemy_query = world.query_filtered::<Entity, With<Enemy>>();
            if enemy_query.iter(world).next().is_none() {
                should_clear = true;
            }
        }
    }

    if should_clear {
        // Get mutable resources only when needed
        if let Some(mut stage) = world.get_resource_mut::<CurrentStage>() {
            stage.number += 1;
            stage.waiting_for_clear = false;
            println!("Stage cleared! Starting Stage {}...", stage.number);
        }
        if let Some(mut formation_state) = world.get_resource_mut::<FormationState>() {
            formation_state.next_slot_index = 0;
            formation_state.total_spawned_this_stage = 0;
            formation_state.formation_complete = false; // Reset flag for new stage
        }
        if let Some(mut spawn_timer) = world.get_resource_mut::<EnemySpawnTimer>() {
            spawn_timer.timer.reset();
        }
    }
}